@@ -106,6 +106,7 @@
 #'   # Predictive distribution for herds of size 20
 #'   # (perhaps a bias adjustment should be applied; see "sophisticated" vignette)
 #'   pred.incidence <- coda::as.mcmc(regrid(cbpp.rg), likelihood = "binomial", trials = 20)
+#'   summary(pred.incidence)
 #' }
 as.mcmc.emmGrid = function(x, names = TRUE, sep.chains = TRUE, 
                            likelihood, NE.include = FALSE, ...) {
@@ -591,7 +592,9 @@ emm_basis.stanreg = function(object, trms, xlev, grid, mode, rescale, ...) {
         
         misc$respName = as.character.default(terms(object))[2]
     }
-    samp = as.matrix(object$stanfit)[, nms, drop = FALSE]
+    samp = as.matrix(object$stanfit)
+    nms = intersect(nms, colnames(samp)) # in case some are excl by rank def.
+    samp = samp[, nms, drop = FALSE]
     attr(samp, "n.chains") = object$stanfit@sim$chains
 
     bhat = apply(samp, 2, mean)
