@@ -76,6 +76,12 @@ str.emmGrid <- function(object, ...) {
             showlevs(levs[[nm]])
         cat("\n")
     }
+    if (length(nuis <- object@roles$nuisance) > 0) {
+        cat("Nuisance factors that have been collapsed by averaging:\n    ")
+        tmp = paste0(names(nuis), "(", sapply(nuis, length), ")")
+        cat(paste(tmp, collapse = ", "))
+        cat("\n")
+    }
     if(!is.null(object@model.info$nesting)) {
         cat("Nesting structure:  ")
         cat(.fmt.nest(object@model.info$nesting))
@@ -378,7 +384,7 @@ update.emmGrid = function(object, ..., silent = FALSE) {
                     warning("Changes to levels may have altered nesting structure.\n",
                             "You likely need to also run 'update(..., nesting = ...)'")
                 object@levels = lvls
-                for (nm in c(".wgt.", ".offset"))
+                for (nm in c(".wgt.", ".offset."))
                         grd[[nm]] = object@grid[[nm]]
                 object@grid = grd
                 object@roles$predictors = misc$pri.vars = names(lvls)
@@ -497,6 +503,14 @@ update.emmGrid = function(object, ..., silent = FALSE) {
 #'   main effects but included them in interactions. This does not change the
 #'   model fit, but it produces a different parameterization that is picked
 #'   up when the reference grid is constructed. Defaults to \code{TRUE}.}
+#' \item{\code{rg.limit}}{An integer value setting a limit on the number of rows
+#'   in a newly constructed reference grid. This is checked based on the number of
+#'   levels of the factors involved; but it excludes the levels of any multivariate
+#'   responses because those are not yet known. The reference grid consists of all
+#'   possible combinations of the predictors, and this can become huge if there are
+#'   several factors. An error is thrown if this limit is exceeded. One can use the 
+#'   \code{nuisance} argument of \code{\link{ref_grid}} to collapse on nuisance
+#'   factors, thus making the grid smaller. Defaults to 10,000.}
 #' \item{\code{simplify.names}}{A logical value controlling whether to
 #'   simplify (when possible) names in the model formula that refer to datasets --
 #'   for example, should we simplify a predictor name like \dQuote{\code{data$trt}}
@@ -650,6 +664,7 @@ emm_defaults = list (
     back.bias.adj = FALSE,    # Try to bias-adjust back-transformations?
     opt.digits = TRUE,        # optimize displayed digits?
     enable.submodel = TRUE,   # enable saving extra info for submodel
+    rg.limit = 10000,         # limit on number of rows in a reference grid
     lmer.df = "kenward-roger",  # Use Kenward-Roger for df
     disable.pbkrtest = FALSE, # whether to bypass pbkrtest routines for lmerMod
     pbkrtest.limit = 3000,    # limit on N for enabling K-R
@@ -895,9 +910,10 @@ emm_defaults = list (
 #' degrees-of-freedom method is inherited from the previous method at
 #' the time of re-gridding.
 #'
-#' @note Another way to use \code{regrid} is to supply a \code{transform} 
+#' @note Another way to use \code{regrid} is to supply a \code{regrid} 
 #'   argument to \code{\link{ref_grid}} (either directly of indirectly via
-#'   \code{\link{emmeans}}). This is often a simpler approach if the reference
+#'   \code{\link{emmeans}}), in which case its value is passed to \code{regrid} as
+#'   \code{transform}. This is often a simpler approach if the reference
 #'   grid has not already been constructed.
 #'
 #' @return An \code{emmGrid} object with the requested changes
@@ -915,7 +931,7 @@ emm_defaults = list (
 #' (emm2 <- emmeans(regrid(rg, transform = "response"), "source"))
 #' pairs(emm2)  ## We obtain DIFFERENCES
 #' # Same result, useful if we hadn't already created 'rg'
-#' # emm2 <- emmeans(pigs.lm, "source", transform = "response")
+#' # emm2 <- emmeans(pigs.lm, "source", regrid = "response")
 #' 
 #' # Simulate a sample of regression coefficients
 #' set.seed(2.71828)
@@ -960,9 +976,14 @@ regrid = function(object, transform = c("response", "mu", "unlink", "none", "pas
     
     est = .est.se.df(object, do.se = TRUE) ###FALSE)
     estble = !(is.na(est[[1]]))
-    object@V = vcov(object)[estble, estble, drop=FALSE]
+    object@V = vcov(object)[estble, estble, drop = FALSE]
     object@bhat = est[[1]]
     object@linfct = diag(1, length(estble))
+    if (!is.null(disp <- object@misc$display)) {  # fix up for the bookkeeping in nested models
+        object@V = object@V[disp, disp, drop = FALSE]
+        object@linfct = matrix(0, nrow = length(disp), ncol = length(estble))
+        object@linfct[disp, ] = diag(1, length(estble))
+    }
     if(all(estble))
         object@nbasis = estimability::all.estble
     else
